Public Catalogs
===============================================================================

The LINCC Frameworks team has built the import tool hoping to handle catalogs
in various formats. We've learned some lessons in importing public data sets, 
and provide steps to import those catalogs in case these hints help anyone else.

.. note::
   These are datasets that our team has data rights to. We make no guarantees
   about the data rights of others, the quality of the datasets, or their
   availability.

   Further, please respect the publication policy associated with the datasets.

.. toctree::
   :maxdepth: 1

   allwise
   neowise
   panstarrs
   sdss
   tic
   zubercal

.. tip::
   Want to see more?

   Have you used this tool with a dataset, and you want to help others with 
   the idiosyncrasies? Is there a commonly used public dataset that you'd like
   some tips for importing? :doc:`/guide/contact`